Installation
============

To install ``nukedatastore``, type:

.. code-block:: bash

    $ pip install nukedatastore

Open Nuke's ``init.py`` file and add:

.. code-block:: python

    nuke.pluginAddPath('/path/to/your/local/python/site-packages')
